@@ -42,7 +42,6 @@ class Get_ASM_Consume:
         headers = {
             'Accept': 'application/json, text/javascript, */*; q=0.01',
             'X-Apple-Widget-Key': self.X_Apple_Widget_Key,
-            'X-Requested-With': 'XMLHttpRequest',
             'Content-Type': 'application/json',
             "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/78.0.3904.87 Safari/537.36"
         }
@@ -55,12 +54,6 @@ class Get_ASM_Consume:
 
             # 模拟登陆；
             url = 'https://appleid.apple.com/widget/account/repair?trustedWidgetDomain=https%3A%2F%2Fidmsa.apple.com&widgetKey=a01459d797984726ee0914a7097e53fad42b70e1f08d09294d14523a1d4f61e1&rv=1&language=zh_CN_CHN'
-            headers = {
-                'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9',
-                'Connection': 'keep-alive',
-                'Host': 'appleid.apple.com',
-                'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/85.0.4183.102 Safari/537.3'
-            }
             res = session.get(url, headers=headers, verify=False)
             if res.status_code == 200:
                 print('...模拟访问网页成功...')
@@ -69,30 +62,17 @@ class Get_ASM_Consume:
                 url = 'https://idmsa.apple.com/appleauth/auth/repair/complete'
                 headers = {
                     'Accept': 'application/json;charset=utf-8',
-                    'Connection': 'keep-alive',
                     'Content-Type': 'application/json',
-                    'Host': 'idmsa.apple.com',
                     'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/85.0.4183.102 Safari/537.36',
                     'scnt': scnt,
                     'X-Apple-Repair-Session-Token': X_Apple_Session_Token,
                     'X-Apple-ID-Session-Id': X_Apple_ID_Session_Id,
-                    ''
                     'X-Apple-Widget-Key': self.X_Apple_Widget_Key,
-                    'X-Requested-With': 'XMLHttpRequest'
                 }
                 res = session.post(url, headers=headers, verify=False)
                 print('...模拟登陆网页成功...')
                 if res.status_code == 204:
                     url = 'https://app-ads.apple.com/cm/api/v1/startup'
-                    headers = {
-                        'Accept': 'application/json, text/javascript, */*; q=0.01',
-                        'Connection': 'keep-alive',
-                        'Content-Type': 'application/json',
-                        'Host': 'app-ads.apple.com',
-                        'Referer': 'https://appleid.apple.com/widget/account/repair?trustedWidgetDomain=https%3A%2F%2Fidmsa.apple.com&widgetKey=a01459d797984726ee0914a7097e53fad42b70e1f08d09294d14523a1d4f61e1&rv=1&language=zh_CN_CHN',
-                        'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/85.0.4183.102 Safari/537.36',
-                        'X-Requested-With': 'XMLHttpRequest'
-                    }
                     res = session.get(url, headers=headers, verify=False)
                     self.defOrg_id = res.json()['data']['userDetails']['defOrg']
                     if res.status_code == 200:
@@ -114,8 +94,15 @@ class Get_ASM_Consume:
             print('...模拟启动浏览器失败...请重试...')
             return '当前接口请求异常: %s' %(url)
 
-    def asm_credits(self):
-        url = 'https://app-ads.apple.com/cm/api/v1/orgs/%s/locdetails?currencyCode=RMB,USD' %(self.defOrg_id)
+    def asm_credits(self, money_type=''):
+        """
+            * 获取账户余额，默认获取账户自有货币；
+            * 可修改为RMB,USD，即人民币；
+        """
+        if len(money_type) > 0:
+            url = 'https://app-ads.apple.com/cm/api/v1/orgs/%s/locdetails?currencyCode=%s' %(self.defOrg_id, money_type)
+        else:
+            url = 'https://app-ads.apple.com/cm/api/v1/orgs/%s/locdetails' % (self.defOrg_id)
         headers = {
             'Host': 'app-ads.apple.com',
             'Connection': 'keep-alive',
@@ -128,7 +115,7 @@ class Get_ASM_Consume:
         money_unit = res.json()['data']['availableCredit'][0]['availableAmount']['currencyCode']
         return money_value, money_unit
 
-    def asm_consume(self, company_name=''):
+    def asm_consume(self, company_name='', money_type=''):
         push_text_list = []  # 汇总推送的内容；
         df_new = pd.DataFrame({})  # 创建个当天的；
         res_status = self.asm_login()
@@ -147,7 +134,7 @@ class Get_ASM_Consume:
         self.today_file_path = '%s%s_%s-%s' %(self.file_path, self.today_date, company_name, self.file_name)
         ####### 重置文件区 #######
         if '异常' not in res_status:
-            # 删除旧文件
+            # 删除旧文件；
             os.system('rm -rf %s' % (self.today_file_path))
             try:
                 df = pd.read_excel('%s' %(self.yes_file_path))
@@ -282,7 +269,7 @@ class Get_ASM_Consume:
                     break
 
             # 存为实例Excel；
-            today_credits_info = self.asm_credits()
+            today_credits_info = self.asm_credits(money_type)
             today_credits_num = today_credits_info[0]
             print('当前账户可用信用额度：', today_credits_num)
             df_new = df_new.append(pd.DataFrame({
@@ -355,39 +342,51 @@ class Get_ASM_Consume:
         if len(company_name) > 0:
             self.get_soid_token(company_name)
         url = 'https://app-ads.apple.com/cm/api/v1/doc/find'
-        offset_num = 0
-        res_list = []
-        fileid_list = []
-        while True:
-            print('正在获取第【%s】页的上传文件列表' %(int(offset_num/50+1)))
-            payload = {
-                "orderBy": [
-                    {
-                        "field": "modificationTime",
-                        "sortOrder": "DESCENDING"
-                    }
-                ],
-                "pagination": {
-                    "offset": offset_num,
-                    "limit": 1000
-                }
-            }
-            headers = {
-                'Host': 'app-ads.apple.com',
-                'Connection': 'keep-alive',
-                'Content-Type': 'application/json;charset=UTF-8',
-                'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/84.0.4147.89 Safari/537.36',
-                'X-XSRF-TOKEN-CM': self.res_token_cm
-            }
-            res = session.post(url, headers=headers, data=json.dumps(payload), verify=False)
-            if len(res.json()['data']) > 0 and res.json()['data'][0]['id'] not in fileid_list:
-                file_list = [i['id'] for i in res.json()['data']]
-                fileid_list += file_list
-                res_list.append(res.json())
-                offset_num += 50
-            else:
-                break
-        return res_list
+        payload = {"conditions":[{"field":"approvalType","operator":"IN","values":["ACCOUNT"]}],"fields":["state"]}
+        headers = {
+            'Host': 'app-ads.apple.com',
+            'Connection': 'keep-alive',
+            'Content-Type': 'application/json;charset=UTF-8',
+            'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/84.0.4147.89 Safari/537.36',
+            'X-XSRF-TOKEN-CM': self.res_token_cm
+        }
+        res = session.post(url, headers=headers, data=json.dumps(payload), verify=False)
+        return res.json()
+
+        # 老版本：
+        # offset_num = 0
+        # res_list = []
+        # fileid_list = []
+        # while True:
+        #     print('正在获取第【%s】页的上传文件列表' %(int(offset_num/50+1)))
+        #     payload = {
+        #         "orderBy": [
+        #             {
+        #                 "field": "modificationTime",
+        #                 "sortOrder": "DESCENDING"
+        #             }
+        #         ],
+        #         "pagination": {
+        #             "offset": offset_num,
+        #             "limit": 1000
+        #         }
+        #     }
+        #     headers = {
+        #         'Host': 'app-ads.apple.com',
+        #         'Connection': 'keep-alive',
+        #         'Content-Type': 'application/json;charset=UTF-8',
+        #         'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/84.0.4147.89 Safari/537.36',
+        #         'X-XSRF-TOKEN-CM': self.res_token_cm
+        #     }
+        #     res = session.post(url, headers=headers, data=json.dumps(payload), verify=False)
+        #     if len(res.json()['data']) > 0 and res.json()['data'][0]['id'] not in fileid_list:
+        #         file_list = [i['id'] for i in res.json()['data']]
+        #         fileid_list += file_list
+        #         res_list.append(res.json())
+        #         offset_num += 50
+        #     else:
+        #         break
+        # return res_list
 
     def get_asm_resStatus(self, company_name=''):
         """
@@ -396,9 +395,7 @@ class Get_ASM_Consume:
         if len(company_name) > 0:
             self.get_soid_token(company_name)
         url = 'https://app-ads.apple.com/cm/api/v1/approval/find'
-        offset_num = 0
-        res_list = []
-        appid_list = []
+        payload = {"orderBy":[{"field":"modificationTime","sortOrder":"DESCENDING"}]}
         headers = {
             'Host': 'app-ads.apple.com',
             'Connection': 'keep-alive',
@@ -406,18 +403,26 @@ class Get_ASM_Consume:
             'user-agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/537.36 Edg/91.0.864.67',
             'X-XSRF-TOKEN-CM': self.res_token_cm
         }
-        while True:
-            print('正在获取第【%s】页的APP审核信息列表' %(int(offset_num/50+1)))
-            payload = {"pagination":{"offset":offset_num,"limit":100}}
-            res = session.post(url, headers=headers, data=json.dumps(payload), verify=False)
-            if len(res.json()['data']) > 0 and res.json()['data'][0] not in appid_list:
-                app_list = [i for i in res.json()['data']]
-                appid_list += app_list
-                res_list.append(res.json())
-                offset_num += 50
-            else:
-                break
-        return res_list
+        res = session.post(url, headers=headers, data=json.dumps(payload), verify=False)
+        return res.json()
+
+        # 老版本：
+        # offset_num = 0
+        # res_list = []
+        # appid_list = []
+        # res_list.append(res.json())
+        # print(res.json())
+        # while True:
+        #     print('正在获取第【%s】页的APP审核信息列表' %(int(offset_num/50+1)))
+        #     payload = {"pagination":{"offset":offset_num,"limit":100}}
+        #     res = session.post(url, headers=headers, data=json.dumps(payload), verify=False)
+        #     if len(res.json()['data']) > 0 and res.json()['data'][0] not in appid_list:
+        #         app_list = [i for i in res.json()['data']]
+        #         appid_list += app_list
+        #         res_list.append(res.json())
+        #         offset_num += 50
+        #     else:
+        #         break
 
     def get_plan_status(self, soid, start_date=today_date-datetime.timedelta(6), end_date=today_date, timezone='UTC'):
         """
